package com.jqtx.windows.job;

import cn.hutool.core.util.IdUtil;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.jqtx.infrastructure.oss.starter.config.OssUtils;
import com.jqtx.windows.component.CreditComponent;
import com.jqtx.windows.component.LoanComponent;
import com.jqtx.windows.component.enums.ZNPostUrlEnum;
import com.jqtx.windows.component.model.CreditModel;
import com.jqtx.windows.component.model.LoanModel;
import com.jqtx.windows.component.model.ZyJsonResult;
import com.jqtx.windows.infrastructure.feign.IProtocalFeignService;
import com.jqtx.windows.utils.AbcHttpClient;
import com.xxl.job.core.handler.annotation.XxlJob;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.time.DateFormatUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;
import java.util.UUID;

@Component
@Slf4j
public class ProtocolJob {
    @Autowired
    private CreditComponent creditComponent;

    @Autowired
    private AbcHttpClient abcHttpClient;

    @Autowired
    private IProtocalFeignService iProtocalFeignService;
    @Autowired
    private LoanComponent loanComponent;

    @Autowired
    private OssUtils ossUtils;

    @XxlJob("protocolJob")
    public void run() {
        List<CreditModel> creditModels = creditComponent.getListModelByCreditThirdToken("INIT");
        creditModels.parallelStream().forEach(p -> {
            LoanModel loanModel = loanComponent.getByOrderNo(p.getOrderNo());
            String protocolUrl = iProtocalFeignService.getFilePathPdf(loanModel.getLoanNo(), "own-rongdan").getResult();
            if (protocolUrl != null) {
                String path = ossUtils.generateTempURLPrivateDomain(protocolUrl);
                JSONObject thirdCredit = new JSONObject();
                thirdCredit.put("orderNo", loanModel.getOrderNo());
                thirdCredit.put("loanNo", loanModel.getLoanNo());
                thirdCredit.put("transNo", IdUtil.fastSimpleUUID());
                thirdCredit.put("contractFileUrl", path);
                ZyJsonResult zyJsonResult = abcHttpClient.postRequest(thirdCredit.toJSONString(), ZNPostUrlEnum.PROTOCOL_CALL.getCode());
                log.info("zyJsonResult:[{}]",JSONObject.toJSONString(zyJsonResult));
                p.setCreditThirdToken("FINISHED");
                creditComponent.updateByOrderNo(p.getOrderNo(),p);
            }
        });


    }


}
